juju.exceptions
===============

.. rubric:: Summary

.. automembersummary:: juju.exceptions

.. rubric:: Reference

.. automodule:: juju.exceptions
    :members:
    :undoc-members:
    :show-inheritance:
